about summary refs log tree commit diff
path: root/include/afl-fuzz.h
diff options
context:
space:
mode:
authorvan Hauser <vh@thc.org>2021-06-27 10:22:18 +0200
committerGitHub <noreply@github.com>2021-06-27 10:22:18 +0200
commit7038e56da3952c89a51596180578153918ce6eee (patch)
treeea6df93d3c002ecc2e33c8b761fe5263eeb978e0 /include/afl-fuzz.h
parent6a3877dcd35d31eb79bebbc30ffe70ac0342743e (diff)
downloadafl++-7038e56da3952c89a51596180578153918ce6eee.tar.gz
Select (#995)
* favor unfuzzed

* fix

* reinit table after a new fuzz
Diffstat (limited to 'include/afl-fuzz.h')
-rw-r--r--include/afl-fuzz.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/afl-fuzz.h b/include/afl-fuzz.h
index 2920f905..2e2c78ef 100644
--- a/include/afl-fuzz.h
+++ b/include/afl-fuzz.h
@@ -519,7 +519,8 @@ typedef struct afl_state {
       shmem_testcase_mode,              /* If sharedmem testcases are used  */
       expand_havoc,                /* perform expensive havoc after no find */
       cycle_schedules,                  /* cycle power schedules?           */
-      old_seed_selection;               /* use vanilla afl seed selection   */
+      old_seed_selection,               /* use vanilla afl seed selection   */
+      reinit_table;                     /* reinit the queue weight table    */
 
   u8 *virgin_bits,                      /* Regions yet untouched by fuzzing */
       *virgin_tmout,                    /* Bits we haven't seen in tmouts   */